@@ -51,7 +51,7 @@ def arg_parser():
     upload_file_path = args.path
 
     if args.check:
-        check_upload_file.check_upload_file(upload_file_path, version_name)
+        yaml_parser.parse_config()
         logger.log(message="All prerequisites met.", log_level="info", to_file=True, to_terminal=True)
         sys.exit(0)
     elif args.upload:
