@@ -55,10 +55,13 @@ def parse_config():
         else:
             admin_interface = "https://software-api-admin.robinradar.systems"
             doc_pages = "https://robinradar.atlassian.net/wiki/spaces/DEV/pages/284033095/Software+Deployment+API"
-            print(f"Error: no config file found.")
-            print(f"Please browse to {admin_interface} to create a config file.")
-            print(f"Please browse to {doc_pages} to learn how to create a config file.")
-            sys.exit(0)
+            print(f"Config file not found in {cfg_file} directory.")
+            print(f"Checking next directory...")
+    if not config:
+        print(f"Error: no config file found.")
+        print(f"Please browse to {admin_interface} to create a config file.")
+        print(f"Please browse to {doc_pages} to learn how to create a config file.")
+        sys.exit(0)
 
     check_and_ask(config)
 
